# cleanser
[![Build Status](https://mholtzscher.visualstudio.com/cleanser/_apis/build/status/cleanser-CI?branchName=master)](https://mholtzscher.visualstudio.com/cleanser/_build/latest?definitionId=2&branchName=master)
